netapp_ontap.models.s3_bucket_lifecycle_expiration API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.s3_bucket_lifecycle_expiration`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class S3BucketLifecycleExpirationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3BucketLifecycleExpiration object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `expired_object_delete_marker: bool GET POST PATCH`

    Cleanup object delete markers.

  `links: SelfLink GET`

    The links field of the s3_bucket_lifecycle_expiration.

  `object_age_days: Size GET POST PATCH`

    Number of days since creation after which objects can be deleted. This cannot be used along with object_expiry_date.

    Example: 100

  `object_expiry_date: ImpreciseDateTime GET POST PATCH`

    Specific date from when objects can expire. This cannot be used with object_age_days.

    Example: 2039-09-23T00:00:00.000+0000